<?php
/**
 * Custom Post Types Admin
 *
 * Add taxonomy filters and thumbnails.
 */
class Custom_Post_Type_Admin {

	protected $registration_handler;
	protected $show_thumbnail;

	public function __construct( $registration_handler ) {
		$this->registration_handler = $registration_handler;
		
		$post_types_thumb = array( 'emd_service', 'emd_slide', 'emd_staff', 'emd_testimonial', 'emd_work' );
		$this->show_thumbnail = in_array( $registration_handler->post_type, $post_types_thumb ) ? true : false;
	}

	public function init() {
		
		if ( $this->show_thumbnail ) {

			// Add thumbnail support for custom post type
			add_theme_support( 'post-thumbnails', array( $this->registration_handler->post_type ) );

			// Add thumbnails to column view
			add_filter( 'manage_' . $this->registration_handler->post_type . '_posts_columns', array( $this, 'add_thumbnail_column'), 10, 1 );
			add_action( 'manage_posts_custom_column', array( $this, 'display_thumbnail' ), 10, 2 );
		}

		// Allow filtering of posts by taxonomy in the admin view
		add_action( 'restrict_manage_posts', array( $this, 'add_taxonomy_filters' ) );

		if ( $this->show_thumbnail ) {
			// Add styles to admin <head> section
			add_action( 'admin_head', array( $this, 'post_table_styles' ) );
		}
	}

	/**
	 * Add columns to Custom Post Type list screen.
	 */
	public function add_thumbnail_column( $columns ) {
		$theme_slug = get_option( 'stylesheet' );
		if ( strpos( $theme_slug, '-child' ) !== false ) {
			$theme_slug = substr( $theme_slug, 0, strpos( $theme_slug, '-child' ) );
		}
		
		global ${ $theme_slug . "_config" };
		$translations = ${ $theme_slug . "_config" }['translations'];
		
		$columns['thumbnail'] = ! empty( $translations['image'] ) ? $translations['image'] : __( 'Image', 'benchmark-cpts' );
		return $columns;
	}

	/**
	 * Custom column callback
	 */
	public function display_thumbnail( $column, $id ) {
		// display thumbnail only for custom posts
		if ( get_post_type( $id ) == $this->registration_handler->post_type ) {
			switch ( $column ) {
				case 'thumbnail':
					$image_src = wp_get_attachment_thumb_url( get_post_thumbnail_id( $id ) );
					$image_alt = trim( strip_tags( get_post_meta( get_post_thumbnail_id( $id ), '_wp_attachment_image_alt', true ) ) );
					if ( $image_src ) {
						echo '<img src="' . $image_src . '" alt="' . esc_attr( $image_alt ) . '" width="36" height="36">';
					}
					break;
			}
		}
	}

	/**
	 * Add taxonomy (custom categories/groups) filter to the Custom Post Type list page.
	 */
	public function add_taxonomy_filters() {
		global $typenow;

		if ( $this->registration_handler->post_type !== $typenow ) {
			return;
		}
		foreach ( $this->registration_handler->taxonomies as $tax_slug ) {
			echo $this->build_taxonomy_filter( $tax_slug );
			break; // only custom categories/groups filter is added
		}
	}

	/**
	 * Build an individual dropdown filter.
	 */
	protected function build_taxonomy_filter( $tax_slug ) {
		$terms = get_terms( $tax_slug );
		if ( ! count( $terms ) ) {
			return '';
		}

		$tax_obj = get_taxonomy( $tax_slug );
		$tax_name = $tax_obj->labels->all_items;
		$current_tax_slug = isset( $_GET[$tax_slug] ) ? $_GET[$tax_slug] : false;

		$filter = '<select name="' . esc_attr( $tax_slug ) . '" id="' . esc_attr( $tax_slug ) . '" class="postform">';
		$filter .= '<option value="0">' . esc_html( $tax_name ) .'</option>';
		$filter .= $this->build_term_options( $terms, $current_tax_slug );
		$filter .= '</select>';

		return $filter;
	}

	/**
	 * Build a series of option elements from an array.
	 * Also checks to see if one of the options is selected.
	 */
	protected function build_term_options( $terms, $current_tax_slug ) {
		$options = '';
		foreach ( $terms as $term ) {
			$options .= sprintf(
				'<option value="%s"%s />%s</option>',
				esc_attr( $term->slug ),
				selected( $current_tax_slug, $term->slug, false ),
				esc_html( $term->name . ' (' . $term->count . ')' )
			);
		}
		return $options;
	}

	/**
	 * Add styles to admin <head> section.
	 */
	public function post_table_styles() {
		$screen = get_current_screen();
		if ( $screen->id != 'edit-' . $this->registration_handler->post_type ) { // Styling only needed on Custom Post Type page
			return;
		}
		?>
		<style>
			.fixed .column-date { width: 12%; }
			.fixed .column-thumbnail { width: 80px; }
		</style>
		<?php
	}

}